import{_ as C}from"./logo.084e5d7c.js";import{t as I,b as r,eu as y,eE as w,eF as B,e as h,d as k,eA as D,a as L,u as e,c,bD as S,w as t,f as o,aA as l,eD as i,b$ as f,cK as b,cG as N,eH as V,eC as E,eZ as R,b8 as T,ew as $}from"./outputWidgets.0ed3a637.js";import{a as g}from"./router.d8af0f7d.js";import{a as F}from"./asyncComputed.054ae312.js";import{A as H,B as P,a as j,c as G}from"./index.e62d6d0c.js";import{c as K}from"./Text.e89a9af1.js";(function(){try{var a=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},s=new Error().stack;s&&(a._sentryDebugIds=a._sentryDebugIds||{},a._sentryDebugIds[s]="552de885-2c9e-4df6-b15e-a8aa53643180",a._sentryDebugIdIdentifier="sentry-dbid-552de885-2c9e-4df6-b15e-a8aa53643180")}catch{}})();const M={},A=a=>(w("data-v-439be421"),a=a(),B(),a),U={class:"logo"},Z=A(()=>h("img",{class:"logo-img",src:C,alt:"Abstra cloud logo"},null,-1)),q=A(()=>h("span",null,"Abstra Cloud",-1)),z=[Z,q];function J(a,s){return r(),y("div",U,z)}const O=I(M,[["render",J],["__scopeId","data-v-439be421"]]),Q=k({__name:"LoginBlock",setup(a){function s(p){const m=p.split("@")[0];return V.exports.kebabCase(m).toUpperCase().split("-").slice(0,2).map(_=>_[0]).join("")}const u=D(),{result:n,loading:d,refetch:v}=F(async()=>g.getAuthor());function x(){g.removeAuthor(),v(),u.push({name:"login"})}return(p,m)=>{const _=L("router-link");return e(d)?(r(),c(e(S),{key:0})):e(n)?(r(),c(e(N),{key:1,placement:"bottomRight"},{content:t(()=>[o(e(b),{direction:"vertical"},{default:t(()=>[o(e(K),null,{default:t(()=>[l(i(e(n).claims.email),1)]),_:1}),o(e(f),{onClick:x},{default:t(()=>[l("Logout")]),_:1})]),_:1})]),default:t(()=>[o(e(b),{align:"center",style:{cursor:"pointer"}},{default:t(()=>[o(e(H),null,{default:t(()=>[l(i(s(e(n).claims.email)),1)]),_:1})]),_:1})]),_:1})):(r(),c(e(f),{key:2},{default:t(()=>[o(_,{to:"/login"},{default:t(()=>[l("Login")]),_:1})]),_:1}))}}}),oe=k({__name:"Navbar",props:{breadcrumb:{}},setup(a){return(s,u)=>(r(),c(e(G),{style:{padding:"5px 10px"}},{breadcrumb:t(()=>[s.breadcrumb?(r(),c(e(P),{key:0},{default:t(()=>[(r(!0),y(T,null,E(s.breadcrumb,(n,d)=>(r(),c(e(j),{key:d},{default:t(()=>[o(e(R),{to:n.path},{default:t(()=>[l(i(n.label),1)]),_:2},1032,["to"])]),_:2},1024))),128))]),_:1})):$("",!0)]),title:t(()=>[o(O)]),extra:t(()=>[o(Q)]),_:1}))}});export{oe as _};
//# sourceMappingURL=Navbar.vue_vue_type_script_setup_true_lang.01a04e6e.js.map
