import"./outputWidgets.0ed3a637.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="ae9cabc7-3955-4b88-accc-6203709eb0c5",e._sentryDebugIdIdentifier="sentry-dbid-ae9cabc7-3955-4b88-accc-6203709eb0c5")}catch{}})();const c=e=>{try{return new URL(e),!0}catch{return!1}};export{c as i};
//# sourceMappingURL=url.4f7be002.js.map
