import{t as o,a as i,b as a,c as d,i as c,T as p,j as u,P as f,C as _,M as l,s as g,k as s,l as m,m as b,n as y,p as v}from"./outputWidgets.0ed3a637.js";import{u as w,s as h,a as r}from"./index.7da893da.js";import"./pubsub.5dd4605f.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="d2dce03f-3195-4dd6-bd4a-e085fa9cfb64",e._sentryDebugIdIdentifier="sentry-dbid-d2dce03f-3195-4dd6-bd4a-e085fa9cfb64")}catch{}})();const I={};function k(e,t){const n=i("router-view");return a(),d(n,{style:{"min-height":"100vh","box-sizing":"border-box",width:"100%"}})}const x=o(I,[["render",k]]);class P{static init(){setInterval(()=>fetch("/_version"),20*1e3)}}(async()=>{await Promise.all([w(),h()]);const e=c({render:()=>m(x)});p.init(),u(e,r),P.init(),e.use(r),e.use(f),e.mount("#app"),e.component("VSelect",_),e.component("Markdown",l),e.component("Message",g),s(e,b),s(e,y),s(e,v)})();
//# sourceMappingURL=player.c2e528be.js.map
