import{cE as d}from"./outputWidgets.0ed3a637.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},r=new Error().stack;r&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[r]="e4b1a21e-8946-43ad-882b-99dbb8ff67ee",e._sentryDebugIdIdentifier="sentry-dbid-e4b1a21e-8946-43ad-882b-99dbb8ff67ee")}catch{}})();const t=(e,r)=>{d.error({message:e,description:r})};export{t as p};
//# sourceMappingURL=popupNotifcation.eef316e3.js.map
