import{ee as p,ab as b,U as a,f as d,O as y}from"./outputWidgets.0ed3a637.js";import{B as c,a as u}from"./Base.69739fb7.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[o]="6f7f2a4d-5fa9-44bb-a6aa-e3974738f175",e._sentryDebugIdIdentifier="sentry-dbid-6f7f2a4d-5fa9-44bb-a6aa-e3974738f175")}catch{}})();var g=globalThis&&globalThis.__rest||function(e,o){var n={};for(var t in e)Object.prototype.hasOwnProperty.call(e,t)&&o.indexOf(t)<0&&(n[t]=e[t]);if(e!=null&&typeof Object.getOwnPropertySymbols=="function")for(var r=0,t=Object.getOwnPropertySymbols(e);r<t.length;r++)o.indexOf(t[r])<0&&Object.prototype.propertyIsEnumerable.call(e,t[r])&&(n[t[r]]=e[t[r]]);return n};const m=p(1,2,3,4,5),_=()=>a(a({},y(u(),["component","strong"])),{level:Number}),s=(e,o)=>{let{slots:n,attrs:t}=o;const{level:r=1}=e,f=g(e,["level"]);let l;m.includes(r)?l=`h${r}`:(b(),l="h1");const i=a(a(a({},f),{component:l}),t);return d(c,i,n)};s.displayName="ATypographyTitle";s.inheritAttrs=!1;s.props=_();const T=s;export{T as A};
//# sourceMappingURL=Title.53f943d2.js.map
