import"./outputWidgets.0ed3a637.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},i=new Error().stack;i&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[i]="7747cd0f-722a-423a-bc47-1268b30f67fe",e._sentryDebugIdIdentifier="sentry-dbid-7747cd0f-722a-423a-bc47-1268b30f67fe")}catch{}})();function f(e,i){const n=document,a=e.matched.slice().reverse().find(t=>t.meta&&t.meta.title),d=i.matched.slice().reverse().find(t=>t.meta&&t.meta.metaTags);a?n.title=a.meta.title:d&&(n.title=d.meta.title)}export{f as u};
//# sourceMappingURL=index.230ffe19.js.map
