import{d,eB as b,G as m,a as g,b as f,c as v,w as i,f as s}from"./outputWidgets.0ed3a637.js";import{B as _}from"./BaseLayout.93df0706.js";import{a as y}from"./asyncComputed.054ae312.js";import{P as h}from"./project.2789fa4a.js";import"./router.d8af0f7d.js";import{O as z}from"./organization.bd1b7f8e.js";import"./columns.15b333c9.js";import{_ as j}from"./Navbar.vue_vue_type_script_setup_true_lang.01a04e6e.js";import{S as I}from"./Sidebar.c31e6ff4.js";import{z as w,A as B,B as k,C,D as P,E as $,F as x,v as D,x as M,y as S}from"./icons.8d5441dc.js";import"./gateway.678b6185.js";import"./activeRecord.e0ef2424.js";import"./pubsub.5dd4605f.js";import"./Base.69739fb7.js";import"./transButton.3ca23b61.js";import"./Text.e89a9af1.js";import"./Title.53f943d2.js";import"./index.230ffe19.js";import"./logo.084e5d7c.js";import"./index.e62d6d0c.js";import"./Tooltip.0fa91dfe.js";(function(){try{var o=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},r=new Error().stack;r&&(o._sentryDebugIds=o._sentryDebugIds||{},o._sentryDebugIds[r]="3ee5ec93-8371-4043-a95c-f9fb10bfe9d2",o._sentryDebugIdIdentifier="sentry-dbid-3ee5ec93-8371-4043-a95c-f9fb10bfe9d2")}catch{}})();const ea=d({__name:"Project",setup(o){const c=b().params.projectId,{result:a}=y(()=>h.get(c).then(async e=>{const t=await z.get(e.organizationId);return{project:e,organization:t}})),l=m(()=>{var e,t,n,p;return((e=a.value)==null?void 0:e.organization)&&a.value.project?[{label:"My organizations",path:"/organizations"},{label:(n=(t=a.value)==null?void 0:t.organization)==null?void 0:n.name,path:`/organizations/${(p=a.value)==null?void 0:p.organization.id}`},{label:a.value.project.name,path:`/projects/${a.value.project.id}`}]:void 0}),u=m(()=>{var e;return(e=a.value)!=null&&e.project?[{name:"Project",items:[{name:"Builds",path:"builds",icon:w},{name:"Connectors",path:"connectors",icon:B},{name:"Tables",path:"tables",icon:k},{name:"API Keys",path:"api-keys",icon:C},{name:"Env Vars",path:"env-vars",icon:P},{name:"Logs",icon:$,path:"logs",beta:!0},{name:"Settings",icon:x,path:"settings"}]},{name:"Organization",items:[{name:"Projects",icon:D,path:`/organizations/${a.value.project.organizationId}/projects`},{name:"Members",icon:M,path:`/organizations/${a.value.project.organizationId}/members`},{name:"Billing",icon:S,path:`/organizations/${a.value.project.organizationId}/billing`,unavailable:!0}]}]:[]});return(e,t)=>{const n=g("router-view");return f(),v(_,null,{content:i(()=>[s(n)]),navbar:i(()=>[s(j,{class:"nav",breadcrumb:l.value},null,8,["breadcrumb"])]),sidebar:i(()=>[s(I,{class:"sidebar",sections:u.value},null,8,["sections"])]),_:1})}}});export{ea as default};
//# sourceMappingURL=Project.c03b5dc5.js.map
