import{T as c,A as p}from"./TabPane.6209d052.js";import{C as i,A as d}from"./CollapsePanel.c6bd37e2.js";import{N as G,U as g,z as _,B as A,aG as o,aH as T,bn as y,a1 as O,D as P,d as F,dj as E,L as D,G as N,f as L,Q as V,O as W}from"./outputWidgets.0ed3a637.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="23cc973d-a61a-4384-a864-e218fb72410c",e._sentryDebugIdIdentifier="sentry-dbid-23cc973d-a61a-4384-a864-e218fb72410c")}catch{}})();c.TabPane=p;c.install=function(e){return e.component(c.name,c),e.component(p.name,p),e};i.Panel=d;i.install=function(e){return e.component(i.name,i),e.component(d.name,d),e};const b=["wrap","nowrap","wrap-reverse"],v=["flex-start","flex-end","start","end","center","space-between","space-around","space-evenly","stretch","normal","left","right"],C=["center","start","end","flex-start","flex-end","self-start","self-end","baseline","normal","stretch"],z=(e,t)=>{const a={};return b.forEach(n=>{a[`${e}-wrap-${n}`]=t.wrap===n}),a},H=(e,t)=>{const a={};return C.forEach(n=>{a[`${e}-align-${n}`]=t.align===n}),a[`${e}-align-stretch`]=!t.align&&!!t.vertical,a},J=(e,t)=>{const a={};return v.forEach(n=>{a[`${e}-justify-${n}`]=t.justify===n}),a};function M(e,t){return G(g(g(g({},z(e,t)),H(e,t)),J(e,t)))}const B=e=>{const{componentCls:t}=e;return{[t]:{display:"flex","&-vertical":{flexDirection:"column"},"&-rtl":{direction:"rtl"},"&:empty":{display:"none"}}}},Q=e=>{const{componentCls:t}=e;return{[t]:{"&-gap-small":{gap:e.flexGapSM},"&-gap-middle":{gap:e.flexGap},"&-gap-large":{gap:e.flexGapLG}}}},R=e=>{const{componentCls:t}=e,a={};return b.forEach(n=>{a[`${t}-wrap-${n}`]={flexWrap:n}}),a},U=e=>{const{componentCls:t}=e,a={};return C.forEach(n=>{a[`${t}-align-${n}`]={alignItems:n}}),a},X=e=>{const{componentCls:t}=e,a={};return v.forEach(n=>{a[`${t}-justify-${n}`]={justifyContent:n}}),a},q=_("Flex",e=>{const t=A(e,{flexGapSM:e.paddingXS,flexGap:e.padding,flexGapLG:e.paddingLG});return[B(t),Q(t),R(t),U(t),X(t)]});function x(e){return["small","middle","large"].includes(e)}const Y=()=>({prefixCls:o(),vertical:T(),wrap:o(),justify:o(),align:o(),flex:y([Number,String]),gap:y([Number,String]),component:O()});var Z=globalThis&&globalThis.__rest||function(e,t){var a={};for(var n in e)Object.prototype.hasOwnProperty.call(e,n)&&t.indexOf(n)<0&&(a[n]=e[n]);if(e!=null&&typeof Object.getOwnPropertySymbols=="function")for(var l=0,n=Object.getOwnPropertySymbols(e);l<n.length;l++)t.indexOf(n[l])<0&&Object.prototype.propertyIsEnumerable.call(e,n[l])&&(a[n[l]]=e[n[l]]);return a};const k=F({name:"AFlex",inheritAttrs:!1,props:Y(),setup(e,t){let{slots:a,attrs:n}=t;const{flex:l,direction:S}=E(),{prefixCls:r}=D("flex",e),[w,h]=q(r),$=N(()=>{var s;return[r.value,h.value,M(r.value,e),{[`${r.value}-rtl`]:S.value==="rtl",[`${r.value}-gap-${e.gap}`]:x(e.gap),[`${r.value}-vertical`]:(s=e.vertical)!==null&&s!==void 0?s:l==null?void 0:l.value.vertical}]});return()=>{var s;const{flex:m,gap:f,component:j="div"}=e,I=Z(e,["flex","gap","component"]),u={};return m&&(u.flex=m),f&&!x(f)&&(u.gap=`${f}px`),w(L(j,V({class:[n.class,$.value],style:[n.style,u]},W(I,["justify","wrap","align","vertical"])),{default:()=>[(s=a.default)===null||s===void 0?void 0:s.call(a)]}))}}}),ne=P(k);export{ne as A};
//# sourceMappingURL=index.8f72f7ed.js.map
