import{S as p}from"./Sidebar.c31e6ff4.js";import{_ as c}from"./Navbar.vue_vue_type_script_setup_true_lang.01a04e6e.js";import{v as d,x as b,y as l}from"./icons.8d5441dc.js";import{d as u,eB as f,G as g,a as _,b as y,c as v,w as t,f as r}from"./outputWidgets.0ed3a637.js";import{a as w}from"./asyncComputed.054ae312.js";import"./router.d8af0f7d.js";import{O as z}from"./organization.bd1b7f8e.js";import"./columns.15b333c9.js";import{B as h}from"./BaseLayout.93df0706.js";import"./Tooltip.0fa91dfe.js";import"./logo.084e5d7c.js";import"./index.e62d6d0c.js";import"./transButton.3ca23b61.js";import"./Text.e89a9af1.js";import"./Base.69739fb7.js";import"./Title.53f943d2.js";import"./index.230ffe19.js";import"./gateway.678b6185.js";import"./activeRecord.e0ef2424.js";import"./pubsub.5dd4605f.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[o]="c0d7f055-4bb7-45fb-9674-e3debe7b9ad4",e._sentryDebugIdIdentifier="sentry-dbid-c0d7f055-4bb7-45fb-9674-e3debe7b9ad4")}catch{}})();const J=u({__name:"Organization",setup(e){const n=f().params.organizationId,{result:a}=w(()=>z.get(n)),i=g(()=>a.value?[{label:"My organizations",path:"/organizations"},{label:a.value.name,path:`/organizations/${a.value.id}`}]:void 0),s=[{name:"Organization",items:[{name:"Projects",icon:d,path:"projects"},{name:"Members",icon:b,path:"members"},{name:"Billing",icon:l,path:"billing",unavailable:!0}]}];return(I,B)=>{const m=_("router-view");return y(),v(h,null,{navbar:t(()=>[r(c,{breadcrumb:i.value},null,8,["breadcrumb"])]),sidebar:t(()=>[r(p,{class:"sidebar",sections:s})]),content:t(()=>[r(m)]),_:1})}}});export{J as default};
//# sourceMappingURL=Organization.8c4f8dde.js.map
