import{t,b as s,eu as o}from"./outputWidgets.0ed3a637.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},n=new Error().stack;n&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[n]="253264e7-1600-4579-a986-6152f63569d9",e._sentryDebugIdIdentifier="sentry-dbid-253264e7-1600-4579-a986-6152f63569d9")}catch{}})();const r={},i={class:"organization-settings"};function a(e,n){return s(),o("div",i,"Organization settings")}const f=t(r,[["render",a]]);export{f as default};
//# sourceMappingURL=OrganizationSettings.1145872b.js.map
